<?php
/*
 * @version $Id: HEADER 15930 2011-10-30 15:47:55Z tsmr $
 -------------------------------------------------------------------------
 Manufacturersimports plugin for GLPI
 Copyright (C) 2003-2011 by the Manufacturersimports Development Team.

 https://forge.indepnet.net/projects/manufacturersimports
 -------------------------------------------------------------------------

 LICENSE
		
 This file is part of Manufacturersimports.

 Manufacturersimports is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 Manufacturersimports is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with Manufacturersimports. If not, see <http://www.gnu.org/licenses/>.
 --------------------------------------------------------------------------
 */

if (!defined('GLPI_ROOT')) {
	die("Sorry. You can't access directly to this file");
}

class PluginManufacturersimportsConfig extends CommonDBTM {
   
   static $types = array('Computer','Monitor','NetworkEquipment','Peripheral','Printer');
   
   static function getTypeName() {
      global $LANG;

      return $LANG['plugin_manufacturersimports']['config'][6];
   }
   
   function canCreate() {
      return plugin_manufacturersimports_haveRight('manufacturersimports', 'w');
   }

   function canView() {
      return plugin_manufacturersimports_haveRight('manufacturersimports', 'r');
   }
   
   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
      global $LANG;

      if (in_array($item->getType(), self::getTypes(true))
              && plugin_manufacturersimports_haveRight('manufacturersimports', 'r')
                 && !isset($withtemplate) || empty($withtemplate)) {
                 
                  $suppliername = self::checkManufacturerName($item->getType(),$item->getID());
                  if ($suppliername) {
                     return $LANG['plugin_manufacturersimports']['title'][1];
                  }
      }
      return '';
   }

   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
      global $CFG_GLPI;

      if (in_array($item->getType(), self::getTypes(true))) {
         self::showInformationsForm(get_class($item),$item->getID());
         PluginManufacturersimportsModel::showForm(get_class($item),$item->getID());
      }
      return true;
   }
  
	/**
	 * Preconfig datas for standard system
	 * @param $type type of standard system : AD
	 *@return nothing
	 **/
	function preconfig($type) {
      
		switch($type) {
			case 'Dell':
			case 'HP':
			case 'Fujitsu':
			case 'Lenovo':
			case 'Toshiba':
            $supplierclass = "PluginManufacturersimports".$type;
            $supplier = new $supplierclass();
            $infos = $supplier->getSupplierInfo();
            $this->fields["name"]=$infos["name"];
            $this->fields["supplier_url"]=$infos["supplier_url"];
            break;
			default:
            $this->post_getEmpty();
            break;

		}
	}

	function post_addItem() {
		global $DB;

		if ($this->fields["is_recursive"]) {
			$query="DELETE FROM `".$this->getTable()."`
					WHERE `name` = '".$this->fields["name"]."'
					AND `id` != '".$this->fields['id']."' " .
					getEntitiesRestrictRequest('AND',$this->getTable(),'',getSonsOf("glpi_entities",$this->fields["entities_id"]));

			$result=$DB->query($query);
		}
	}

	function post_updateItem($history=1) {
		global $DB;

		if ($this->fields["is_recursive"]) {
			$query="DELETE FROM `".$this->getTable()."`
					WHERE `name` = '".$this->fields["name"]."'
					AND `id` != '".$this->fields["id"]."' " .
					getEntitiesRestrictRequest('AND',$this->getTable(),'',getSonsOf("glpi_entities",$this->fields["entities_id"]));

			$result=$DB->query($query);
		}
	}
	
	static function dropdownSupplier($name, $options=array()) {
      global $LANG;

      $params['value']       = 0;
      $params['toadd']       = array();
      $params['on_change']   = '';

      if (is_array($options) && count($options)) {
         foreach ($options as $key => $val) {
            $params[$key] = $val;
         }
      }

      $items = array();
      if (count($params['toadd'])>0) {
         $items = $params['toadd'];
      }

      $items += self::getSuppliers();

      return Dropdown::showFromArray($name, $items, $params);
   }
   
   static function getSuppliers() {
      global $LANG;
      
      $options[-1] = Dropdown::EMPTY_VALUE;
      $options["Dell"] = "Dell";
      $options["HP"] = "HP";
      $options["Fujitsu"] = "Fujitsu";
      $options["Toshiba"] = "Toshiba";
      $options["Lenovo"] = "Lenovo";
      return $options;
   }
   
   function getSearchOptions() {
      global $LANG;

      $tab = array();

      $tab['common'] = $LANG['plugin_manufacturersimports']['config'][6];

      $tab[1]['table']=$this->getTable();
      $tab[1]['field']='name';
      $tab[1]['name']=$LANG['common'][16];
      $tab[1]['datatype']='itemlink';
      $tab[1]['itemlink_type'] = $this->getType();
      
      $tab[2]['table']='glpi_manufacturers';
      $tab[2]['field']='name';
      $tab[2]['name']=$LANG['plugin_manufacturersimports']['import'][6];
      
      $tab[3]['table']=$this->getTable();
      $tab[3]['field']='supplier_url';
      $tab[3]['name']=$LANG['plugin_manufacturersimports']['config'][0];
      $tab[3]['datatype']='weblink';
      
      $tab[4]['table']='glpi_suppliers';
      $tab[4]['field']='name';
      $tab[4]['name']=$LANG['plugin_manufacturersimports']['config'][2];
      
      $tab[5]['table'] = $this->getTable();
      $tab[5]['field'] = 'warranty_duration';
      $tab[5]['name'] = $LANG['plugin_manufacturersimports']['import'][27];
      $tab[5]['datatype'] = 'integer';
      
      $tab[6]['table'] = $this->getTable();
      $tab[6]['field'] = 'document_adding';
      $tab[6]['name'] = $LANG['plugin_manufacturersimports']['config'][4];
      $tab[6]['datatype']='bool';
      
      $tab[7]['table']  = 'glpi_documentcategories';
      $tab[7]['field']  = 'name';
      $tab[7]['name']   = $LANG['document'][3];
      
      $tab[8]['table'] = $this->getTable();
      $tab[8]['field'] = 'comment_adding';
      $tab[8]['name'] = $LANG['plugin_manufacturersimports']['config'][7];
      $tab[8]['datatype']='bool';
      
      $tab[30]['table']=$this->getTable();
      $tab[30]['field']='id';
      $tab[30]['name']=$LANG['common'][2];
      
      $tab[80]['table']='glpi_entities';
      $tab[80]['field']='completename';
      $tab[80]['name']=$LANG['entity'][0];
      
      $tab[86]['table']    = $this->getTable();
      $tab[86]['field']    = 'is_recursive';
      $tab[86]['name']     = $LANG['entity'][9];
      $tab[86]['datatype'] = 'bool';
      
		return $tab;
   }
	
	function showForm ($ID, $options=array()) {
      global $CFG_GLPI, $LANG;
      
      if (!$this->canView()) return false;
      
      if ($ID>0) {
         $this->check($ID,'r');
      } else {
         $this->check(-1,'w');
         $this->getEmpty();
         if (isset($_GET['preconfig'])) {
            $this->preconfig($_GET['preconfig']);
         } else {
            $_GET['preconfig'] = -1;
         }
      }
      
      $input=array("name"=>$this->fields["name"],"supplier_url"=>$this->fields["supplier_url"]);
      $canedit=$this->can($ID,'w',$input);
      $canrecu=$this->can($ID,'recursive',$input);

      echo "<table class='tab_cadre_fixe'>";
      echo "<tr>";
      echo "<td class='tab_bg_2 center' colspan='2'>".$LANG['ldap'][16]."&nbsp;";
      $opt = array('value' => $_GET['preconfig']);
      $rand = self::dropdownSupplier('supplier', $opt);
      $params = array('supplier'            => '__VALUE__');
      Ajax::updateItemOnSelectEvent("dropdown_supplier$rand", "show_preconfig",
                                          "../ajax/dropdownSuppliers.php",
                                          $params);
      echo "<span id='show_preconfig'>";
      echo "</span>";
      echo "</td>";
      echo "</tr>";
      echo "</table>";
      
      echo "<div id='show_form' ";
      
      if ($_GET['preconfig']==-1 && $ID <= 0) {
         echo "style='display:none;'";
      } else {
         echo "style='display:block;'";
      }
      echo ">";
      $this->showTabs($options);
      $this->showFormHeader($options);

      echo "<tr>";
      echo "<td class='tab_bg_2 center'>".$LANG['common'][16]."</td>";
      echo "<td class='tab_bg_2 left'>";
      echo $this->fields["name"];
      echo "<input type='hidden' name='name' value=\"".$this->fields["name"]."\">\n";
      echo "</td>";
      
      echo "<td class='tab_bg_2 center'>".$LANG['plugin_manufacturersimports']['config'][1]."</td>";
      echo "<td class='tab_bg_2 left'>";
      Dropdown::show('Manufacturer', array('name' => "manufacturers_id",
                                          'value' => $this->fields["manufacturers_id"]));
      echo "</td>";
      echo "</tr>";
      
      echo "<tr>";
      echo "<td class='tab_bg_2 center' colspan='2'>".$LANG['plugin_manufacturersimports']['config'][0]."</td>";
      echo "<td class='tab_bg_2 left' colspan='2'>";
      echo "<input type='text' name='supplier_url' size='100' value='".$this->fields["supplier_url"]."'>";
      echo "</td>";
      echo "</tr>";

      echo "<tr>";
      echo "<td class='tab_bg_2 center' colspan='2'>".$LANG['plugin_manufacturersimports']['config'][2]."</td>";
      echo "<td class='tab_bg_2 left' colspan='2'>";
      Dropdown::show('Supplier', array('name' => "suppliers_id",
                                       'value' => $this->fields["suppliers_id"]));
      echo "</td>";
      echo "</tr>";
      
      if ($this->fields["name"] == "Fujistu") {
         echo "<tr>";
         echo "<td class='tab_bg_2 center' colspan='2'>".$LANG['plugin_manufacturersimports']['config'][3]."</td>";
         echo "<td class='tab_bg_2 left' colspan='2'>";
         Dropdown::showInteger("warranty_duration",$this->fields["warranty_duration"],0,120);
         echo "</td>";
         echo "</tr>";
      } else {
         echo "<input type='hidden' name='warranty_duration' value='0'>\n";
      }
      if ($this->fields["name"] != "Dell") {
         echo "<tr>";
         echo "<td class='tab_bg_2 center' colspan='2'>".$LANG['plugin_manufacturersimports']['config'][4]."</td>";
         echo "<td class='tab_bg_2 left' colspan='2'>";
         Dropdown::showYesNo("document_adding",$this->fields["document_adding"]);
         echo "</td>";
         echo "</tr>";

         echo "<tr>";
         echo "<td class='tab_bg_2 center' colspan='2'>".$LANG['plugin_manufacturersimports']['config'][5]."</td>";
         echo "<td class='tab_bg_2 left' colspan='2'>";
         Dropdown::show('DocumentCategory', array('name' => "documentcategories_id",
                                                   'value' => $this->fields["documentcategories_id"]));
         echo "</td>";
         echo "</tr>";
      }
      echo "<tr>";
      echo "<td class='tab_bg_2 center' colspan='2'>".$LANG['plugin_manufacturersimports']['config'][7]."</td>";
      echo "<td class='tab_bg_2 left' colspan='2'>";
      Dropdown::showYesNo("comment_adding",$this->fields["comment_adding"]);
      echo "</td>";
      echo "</tr>";
      
      $this->showFormButtons($options);
      
      echo "</div>";
      
      $this->addDivForTabs();

      return true;
   }
   
   /**
    * For other plugins, add a type to the linkable types
    *
    * @since version 1.5.0
    *
    * @param $type string class name
   **/
   static function registerType($type) {
      if (!in_array($type, self::$types)) {
         self::$types[] = $type;
      }
   }


   /**
    * Type than could be linked to a Rack
    *
    * @param $all boolean, all type, or only allowed ones
    *
    * @return array of types
   **/
   static function getTypes($all=false) {

      if ($all) {
         return self::$types;
      }

      // Only allowed types
      $types = self::$types;

      foreach ($types as $key => $type) {
         if (!class_exists($type)) {
            continue;
         }

         $item = new $type();
         if (!$item->canView()) {
            unset($types[$key]);
         }
      }
      return $types;
   }
   
   static function checkManufacturerName($itemtype,$items_id) {
      
      $item = new $itemtype();
      $name = false;
      
      if ($item->getFromDB($items_id)) {
         
         $configs = getAllDatasFromTable("glpi_plugin_manufacturersimports_configs");
         
         if (!empty($configs)) {
            foreach ($configs as $config) {
               if ($item->fields["manufacturers_id"] == $config['manufacturers_id']) {
                  $name = $config["name"];
               }
            }
         }   
      }
      return $name;
   }
   
   /**
   * Prints the url to manufacturer informations on items
   *
   * @param $device the device ID
   * @param $type the device type
   * @return nothing (print out a table)
   *
   */
   static function showInformationsForm($itemtype,$items_id) {
      global $DB,$CFG_GLPI,$LANG;

      $item = new $itemtype();
      
      if ($item->getFromDB($items_id)) {
         
         $suppliername = PluginManufacturersimportsConfig::checkManufacturerName($itemtype,$items_id);
         $model = new PluginManufacturersimportsModel();
         $otherserial = $model->checkIfModelNeeds($itemtype,$items_id);
         $url=PluginManufacturersimportsPreImport::selectSupplier($suppliername,$item->fields['serial'],$otherserial);
         
         echo "<div align=\"center\"><table class=\"tab_cadre_fixe\"  cellspacing=\"2\" cellpadding=\"2\">";
         echo "<tr>";
         echo "<th colspan='2'>".$LANG['plugin_manufacturersimports']['title'][1]."</th>";
         echo "</tr>";
         
         echo "<tr class='tab_bg_1'>";
         echo "<td>";
         echo $LANG['plugin_manufacturersimports']['import'][4];
         echo "</td>";
         echo "<td>";
         
         echo "<a href='".$url."' target='_blank'>".$LANG['plugin_manufacturersimports']['import'][6]."</a>";
         echo "</td></tr>";
         echo "</table></div>";

      }
   }
}

?>